@@ -188,6 +188,8 @@ void replace_col(matrix *M, int col_to_set, vector *v);
 
 vector *extract_col(matrix *M, int col_to_get, vector *v);
 
+void Cpred(double *cum,int *nx,int *px,double *xval,int *nxval,double *pred); 
+
 void comptest(double *times,int *Ntimes,int *px,double *cu,double *vcu,
 	      double *vcudif,int *antsim,double *test,double *testOBS,
 	      double *Ut,double *simUt,matrix **W4t,int *weighted,int *antpers); 
@@ -207,8 +209,8 @@ void itfitsemi(double *times,int *Ntimes,double *x,int *delta,int *cause,double
 	       double *testOBS,double *Ut,double *simUt,int *weighted, double *gamma,
 	       double *vargamma,int *semi,double *zsem,int *pg,int *trans,double *gamma2,
 	       int *CA,int *line,int *detail,double *biid,double *gamiid,int *resample,
-	       double *timepow,int *clusters,int *antclust,double *timepowtest,
-	       int *silent,double *convc,double *weights);
+	       double *timepow,int *clusters,int *antclust,double *timepowtest,int *silent,double *convc,
+	       double *weight,double *entry,double *trunkp,int *estimator,int *fixgamma ,int *stratum);
 
 
 void LevenbergMarquardt(matrix *S,matrix *SI,vector *U,vector *delta,double *lm,double *step); 
